@@ -19,7 +19,7 @@ use super::item_traits::PropertyResolver;
 pub type HashType = ImageHash<Vec<u8>>;
 
 /// A single file item with all properties required by image_sieve
-#[derive(Eq, PartialEq, Debug, Clone, Serialize, Deserialize)]
+#[derive(Eq, Debug, Clone, Serialize, Deserialize)]
 pub struct FileItem {
     /// Actual file path
     pub path: PathBuf,
@@ -140,8 +140,7 @@ impl FileItem {
         self.similar.extend(similars.clone().into_iter());
     }
 
-    /// Get the list of similar item indices. Needs a mut because the cleanup of the similar list is done
-    /// in a lazy fashion and might happen here.
+    /// Get the list of similar item indices.
     pub fn get_similars(&self) -> &Vec<usize> {
         &self.similar
     }
@@ -171,19 +170,19 @@ impl FileItem {
     /// Gets a string representing the item type and if it has simlar items or not, if it will be discarded and the item path
     pub fn get_item_string(&self, base_path: &Path) -> String {
         let path = self.path.strip_prefix(base_path).unwrap_or(&self.path);
-        let similars_str = if !self.has_similars() {
-            "\u{1F500} "
-        } else {
-            ""
-        };
+        let similars_str = if !self.has_similars() { "🔀" } else { "" };
         let extension_str = self.extension_to_unicode_icon();
-        let take_over_str = if self.take_over { "" } else { "\u{1F5D1} " };
-        let strings = [
+        let take_over_str = if self.take_over { "" } else { "🗑" };
+        let strings: Vec<&str> = [
             similars_str,
             extension_str,
             take_over_str,
             path.to_str().unwrap(),
-        ];
+        ]
+        .iter()
+        .filter(|&s| !s.is_empty())
+        .copied()
+        .collect();
         strings.join(" ")
     }
 
@@ -200,9 +199,9 @@ impl FileItem {
     /// Get the unicode icon for the extension
     fn extension_to_unicode_icon(&self) -> &str {
         if self.is_image() {
-            "\u{1F4F7} "
+            "📷"
         } else if self.is_video() {
-            "\u{1F4F9} "
+            "📹"
         } else {
             ""
         }
@@ -255,6 +254,13 @@ impl Display for FileItem {
     }
 }
 
+impl PartialEq for FileItem {
+    /// Check if two file items are equal
+    fn eq(&self, other: &Self) -> bool {
+        self.path == other.path
+    }
+}
+
 impl PartialOrd for FileItem {
     fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
         Some(self.cmp(other))
