@@ -200,13 +200,9 @@ impl MainWindow {
             let synchronizer = self.synchronizer.clone();
 
             move || {
-                if let Ok(nfd::Response::Okay(folder)) = nfd::open_pick_folder(Some(
-                    window_weak
-                        .unwrap()
-                        .get_source_directory()
-                        .to_string()
-                        .as_str(),
-                )) {
+                if let Ok(nfd::Response::Okay(folder)) =
+                    nfd::open_pick_folder(get_folder(&window_weak.unwrap().get_source_directory()))
+                {
                     {
                         // Save current item list
                         let item_list = item_list.lock().unwrap();
@@ -237,13 +233,9 @@ impl MainWindow {
             let window_weak = self.window.as_weak();
 
             move || {
-                if let Ok(nfd::Response::Okay(folder)) = nfd::open_pick_folder(Some(
-                    window_weak
-                        .unwrap()
-                        .get_target_directory()
-                        .to_string()
-                        .as_str(),
-                )) {
+                if let Ok(nfd::Response::Okay(folder)) =
+                    nfd::open_pick_folder(get_folder(&window_weak.unwrap().get_target_directory()))
+                {
                     window_weak
                         .unwrap()
                         .set_target_directory(SharedString::from(folder));
@@ -297,11 +289,12 @@ impl MainWindow {
 
             move |finished| {
                 let window = window_weak.unwrap();
-                items_controller.borrow_mut().update_list_model();
-                items_controller.borrow_mut().selected_list_item(
-                    window.get_current_list_item() as usize,
-                    window_weak.clone(),
-                );
+                if items_controller.borrow_mut().update_list_model() {
+                    items_controller.borrow_mut().selected_list_item(
+                        window.get_current_list_item() as usize,
+                        window_weak.clone(),
+                    );
+                }
                 if finished {
                     window.set_calculating_similarities(false);
                 }
@@ -476,3 +469,13 @@ pub fn sieve(
         );
     });
 }
+
+/// Convert a folder setting to an option if the folder exists
+fn get_folder(folder: &SharedString) -> Option<&str> {
+    let folder = folder.as_str();
+    if Path::new(folder).exists() {
+        Some(folder)
+    } else {
+        None
+    }
+}
