@@ -1,6 +1,9 @@
 extern crate ffmpeg_next as ffmpeg;
 
-use super::images::ImageBuffer;
+use super::{
+    images::{get_size, ImageBuffer},
+    resize::resize_image,
+};
 use crate::item_sort_list::{FileItem, Orientation};
 use image::imageops;
 
@@ -9,8 +12,8 @@ const SCREENSHOTS_Y: u32 = 3;
 const VIDEO_PNG: &[u8; 2900] = include_bytes!("video.png");
 
 /// Construct an image for a video by combining 9 frames from the video.
-pub fn get_image_buffer(item: &FileItem, _: u32, _: u32) -> ImageBuffer {
-    create_image_from_video(item).unwrap_or_else(|_| get_alternative_image())
+pub fn get_image_buffer(item: &FileItem, max_width: u32, max_height: u32) -> ImageBuffer {
+    create_image_from_video(item, max_width, max_height).unwrap_or_else(|_| get_alternative_image())
 }
 
 /// Get the alternative image of a video camera
@@ -44,7 +47,11 @@ fn get_position(orientation: Option<&Orientation>, i: u32, width: u32, height: u
 }
 
 /// Create the 3x3 frames image from a video
-fn create_image_from_video(item: &FileItem) -> Result<ImageBuffer, ffmpeg::Error> {
+fn create_image_from_video(
+    item: &FileItem,
+    max_width: u32,
+    max_height: u32,
+) -> Result<ImageBuffer, ffmpeg::Error> {
     let mut input_context = ffmpeg::format::input(&item.path)?;
     if let Some(video_stream) = input_context.streams().best(ffmpeg::media::Type::Video) {
         let stream_index = video_stream.index();
@@ -104,7 +111,14 @@ fn create_image_from_video(item: &FileItem) -> Result<ImageBuffer, ffmpeg::Error
             };
         }
 
-        Ok(buffer)
+        // Scale to max size
+        let (new_width, new_height) =
+            get_size((buffer.width(), buffer.height()), (max_width, max_height));
+        if let Ok(buffer) = resize_image(buffer, new_width, new_height) {
+            Ok(buffer)
+        } else {
+            Err(ffmpeg::Error::InvalidData)
+        }
     } else {
         Err(ffmpeg::Error::StreamNotFound)
     }
@@ -157,13 +171,17 @@ mod tests {
         assert_eq!(image_buffer.width(), SCREENSHOTS_X * 320);
         assert_eq!(image_buffer.height(), SCREENSHOTS_Y * 240);
 
+        let image_buffer = get_image_buffer(&file_item, 200, 100);
+        assert!(image_buffer.width() <= 200);
+        assert!(image_buffer.height() <= 100);
+
         let file_item = FileItem::dummy("tests/test2.MP4", 0, false);
         let image_buffer = get_image_buffer(&file_item, 0, 0);
         assert_eq!(image_buffer.width(), SCREENSHOTS_X * 1920);
         assert_eq!(image_buffer.height(), SCREENSHOTS_Y * 1080);
 
         let file_item = FileItem::dummy("tests/test_invalid.mp4", 0, false);
-        let image_buffer = get_image_buffer(&file_item, 0, 0);
+        let image_buffer = get_image_buffer(&file_item, 10000, 10000);
         assert_eq!(image_buffer.width(), 256);
         assert_eq!(image_buffer.height(), 256);
     }
